/*
 Copyright (c) 2003-2019, CKSource - Frederico Knabben. All rights reserved.
 For licensing, see LICENSE.md or https://ckeditor.com/legal/ckeditor-oss-license
*/
CKEDITOR.plugins.setLang("uicolor","cs",{title:"Výběr barvy rozhraní",options:"Color Options",highlight:"Highlight",selected:"Selected Color",predefined:"Přednastavené sady barev",config:"Vložte tento řetězec do vašeho souboru config.js"});