/*
 Copyright (c) 2003-2019, CKSource - Frederico Knabben. All rights reserved.
 For licensing, see LICENSE.md or https://ckeditor.com/legal/ckeditor-oss-license
*/
CKEDITOR.plugins.setLang("codesnippet","no",{button:"Sett inn kodesnutt",codeContents:"Kode",emptySnippetError:"En kodesnutt kan ikke være tom.",language:"Språk",title:"Kodesnutt",pathName:"kodesnutt"});