CKEDITOR.plugins.setLang("flash","bs",{access:"Script Access",accessAlways:"Always",accessNever:"Never",accessSameDomain:"Same domain",alignAbsBottom:"Abs dole",alignAbsMiddle:"Abs sredina",alignBaseline:"Bazno",alignTextTop:"Vrh teksta",bgcolor:"Boja pozadine",chkFull:"Allow Fullscreen",chkLoop:"Loop",chkMenu:"Enable Flash Menu",chkPlay:"Auto Play",flashvars:"Variables for Flash",hSpace:"HSpace",properties:"Flash Properties",propertiesTab:"Properties",quality:"Quality",qualityAutoHigh:"Auto High",
qualityAutoLow:"Auto Low",qualityBest:"Best",qualityHigh:"High",qualityLow:"Low",qualityMedium:"Medium",scale:"Scale",scaleAll:"Show all",scaleFit:"Exact Fit",scaleNoBorder:"No Border",title:"Flash Properties",vSpace:"VSpace",validateHSpace:"HSpace must be a number.",validateSrc:"Molimo ukucajte URL link",validateVSpace:"VSpace must be a number.",windowMode:"Window mode",windowModeOpaque:"Opaque",windowModeTransparent:"Transparent",windowModeWindow:"Window"});